@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2004-2013 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2004-2014 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <QDebug>
@@ -65,6 +65,7 @@ QList<QVariant> defaultScheme = QList<QVariant>()
                                 << QVariant(100)           // rope modfier   39
                                 << QVariant(100)           // get away time  40
                                 << QVariant(0)             // world edge     41
+                                << QVariant()              // scriptparam    42
                                 ;
 
 AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
@@ -83,6 +84,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
                          << "Timeless"
                          << "Thinking with Portals"
                          << "King Mode"
+						 << "Construction Mode"
                          ;
 
     numberOfDefaultSchemes = predefSchemesNames.size();
@@ -130,6 +132,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
               << "ropepct"             // 39
               << "getawaytime"         // 40
               << "worldedge"           // 41
+              << "scriptparam"         // scriptparam    42
               ;
 
     QList<QVariant> proMode;
@@ -176,6 +179,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> shoppa;
@@ -222,6 +226,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> cleanslate;
@@ -268,6 +273,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> minefield;
@@ -304,7 +310,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(15)            // sudden death   29
             << QVariant(0)             // case prob      30
             << QVariant(0)             // mines time     31
-            << QVariant(80)            // mines number   32
+            << QVariant(200)           // mines number   32
             << QVariant(0)             // mine dud pct   33
             << QVariant(0)             // explosives     34
             << QVariant(35)            // health case pct 35
@@ -314,6 +320,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> barrelmayhem;
@@ -352,7 +359,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(0)             // mines time     31
             << QVariant(0)             // mines number   32
             << QVariant(0)             // mine dud pct   33
-            << QVariant(80)            // explosives     34
+            << QVariant(200)           // explosives     34
             << QVariant(35)            // health case pct 35
             << QVariant(25)            // health case amt 36
             << QVariant(47)            // water rise amt 37
@@ -360,6 +367,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> tunnelhogs;
@@ -406,6 +414,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> forts;
@@ -452,6 +461,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> timeless;
@@ -498,6 +508,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> thinkingportals;
@@ -544,6 +555,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
     QList<QVariant> kingmode;
@@ -590,9 +602,56 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
             << QVariant(100)           // rope modfier   39
             << QVariant(100)           // get away time  40
             << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
             ;
 
-
+	QList<QVariant> construction;
+    construction
+            << predefSchemesNames[11]  // name           0
+            << QVariant(false)         // fortsmode      1
+            << QVariant(false)         // team divide    2
+            << QVariant(false)         // solid land     3
+            << QVariant(false)         // border         4
+            << QVariant(false)         // low gravity    5
+            << QVariant(false)         // laser sight    6
+            << QVariant(false)         // invulnerable   7
+            << QVariant(false)         // reset health   8
+            << QVariant(false)         // vampiric       9
+            << QVariant(false)         // karma          10
+            << QVariant(false)         // artillery      11
+            << QVariant(true)          // random order   12
+            << QVariant(false)          // king           13
+            << QVariant(false)         // place hog      14
+            << QVariant(false)         // shared ammo    15
+            << QVariant(true)         // disable girders 16
+            << QVariant(true)         // disable land objects 17
+            << QVariant(false)         // AI survival    18
+            << QVariant(true)         // inf. attack    19
+            << QVariant(false)         // reset weps     20
+            << QVariant(true)         // per hog ammo   21
+            << QVariant(false)         // no wind        22
+            << QVariant(false)         // more wind      23
+            << QVariant(false)         // tag team       24
+            << QVariant(false)         // bottom border  25
+            << QVariant(100)           // damage modfier 26
+            << QVariant(45)            // turn time      27
+            << QVariant(100)           // init health    28
+            << QVariant(15)            // sudden death   29
+            << QVariant(5)             // case prob      30
+            << QVariant(3)             // mines time     31
+            << QVariant(0)             // mines number   32
+            << QVariant(0)             // mine dud pct   33
+            << QVariant(0)             // explosives     34
+            << QVariant(35)            // health case pct 35
+            << QVariant(25)            // health case amt 36
+            << QVariant(47)            // water rise amt 37
+            << QVariant(5)             // health dec amt 38
+            << QVariant(100)           // rope modfier   39
+            << QVariant(100)           // get away time  40
+            << QVariant(0)             // world edge     41
+            << QVariant()              // scriptparam    42
+            ;
+			
     schemes.append(defaultScheme);
     schemes.append(proMode);
     schemes.append(shoppa);
@@ -604,6 +663,7 @@ AmmoSchemeModel::AmmoSchemeModel(QObject* parent, const QString & fileName) :
     schemes.append(timeless);
     schemes.append(thinkingportals);
     schemes.append(kingmode);
+	schemes.append(construction);
 
 
     int size = fileConfig.beginReadArray("schemes");
@@ -688,7 +748,7 @@ bool AmmoSchemeModel::insertRows(int row, int count, const QModelIndex & parent)
     else
     {
         QList<QVariant> newScheme = schemes[row];
-        newScheme[0] = QVariant(tr("copy of") + " " + newScheme[0].toString());
+        newScheme[0] = QVariant(tr("copy of %1").arg(newScheme[0].toString()));
         schemes.insert(schemes.size(), newScheme);
     }
 
@@ -785,7 +845,7 @@ QVariant NetAmmoSchemeModel::data(const QModelIndex &index, int role) const
     return netScheme[index.column()];
 }
 
-void NetAmmoSchemeModel::setNetSchemeConfig(QStringList & cfg)
+void NetAmmoSchemeModel::setNetSchemeConfig(QStringList cfg)
 {
     if(cfg.size() != netScheme.size())
     {
@@ -793,6 +853,8 @@ void NetAmmoSchemeModel::setNetSchemeConfig(QStringList & cfg)
         return;
     }
 
+    cfg[42] = cfg[42].mid(1);
+
     for(int i = 0; i < cfg.size(); ++i)
         netScheme[i] = QVariant(cfg[i]);
 
