@@ -1,7 +1,7 @@
 /*
  * Hedgewars, a free turn based strategy game
  * Copyright (c) 2007 Igor Ulyanov <iulyanov@gmail.com>
- * Copyright (c) 2004-2013 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2004-2014 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef _CHAT_WIDGET_INCLUDED
@@ -32,6 +32,7 @@
 #include "SDLInteraction.h"
 
 #include "SmartLineEdit.h"
+#include "playerslistmodel.h"
 
 class QTextBrowser;
 class QLineEdit;
@@ -87,6 +88,7 @@ class HWChatWidget : public QWidget
         QString linkedNick(const QString & nickname);
         void beforeContentAdd();
         void afterContentAdd();
+        bool isInGame();
 
         /**
          * @brief Checks whether the message contains a highlight.
@@ -132,6 +134,7 @@ class HWChatWidget : public QWidget
         void consoleCommand(const QString & command);
 
     private:
+        PlayersListModel* m_usersModel;
         bool m_isAdmin;
         QHBoxLayout mainLayout;
         QTextBrowser* chatText;
