@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 
@@ -62,6 +62,22 @@
 #define AMMOLINE_ONEEVERY_DELAY "00000000000000000000000000000000000000000000000000000000"
 #define AMMOLINE_ONEEVERY_CRATE "11111101111111111111111111111111111111111111111111111111"
 
+#define AMMOLINE_HIGHLANDER_QT    "11111191111111111111019111111111100101111101111011001101"
+#define AMMOLINE_HIGHLANDER_PROB  "00000000000000000000000000000000000000000000000000000000"
+#define AMMOLINE_HIGHLANDER_DELAY "00000000000000000000000000000000000000000000000000000000"
+#define AMMOLINE_HIGHLANDER_CRATE "00000000000000000000000000000000000000000000000000000000"
+
+#define AMMOLINE_CONSTRUCTION_QT    "11000190000000100100000000000000000000000000000000000000"
+#define AMMOLINE_CONSTRUCTION_PROB  "11111101111111111111111111111111111111111111111111111111"
+#define AMMOLINE_CONSTRUCTION_DELAY "00000000000000000000000000000000000000000000000000000000"
+#define AMMOLINE_CONSTRUCTION_CRATE "11111101111111111111111111111111111111111111111111111111"
+
+#define AMMOLINE_SHOPPAPRO_QT      "00000099000000000000000000000000000000000000000000000000"
+#define AMMOLINE_SHOPPAPRO_PROB    "44444000440444000000000000004000000000000000000000000000"
+#define AMMOLINE_SHOPPAPRO_DELAY   "00000000000000000000000000000000000000000000000000000000"
+#define AMMOLINE_SHOPPAPRO_CRATE   "11111101111111111111111111111111111111111011011111111211"
+
+
 //When adding new weapons also insert one element in cDefaultAmmos list (hwconsts.cpp.in)
 
 
