@@ -1,32 +1,8 @@
 ObjectList = {}
-PointsBuffer = ''  -- A string to accumulate points in
 
 -- Overall padding for roping freedom
 Padding = 430
 
-function AddPoint(x, y, width, erase)
- PointsBuffer = PointsBuffer .. string.char(band(x,0xff00) / 256 , band(x,0xff) , band(y,0xff00) / 256 , band(y,0xff))
- if width then
-     width = bor(width,0x80)
-     if erase then
-         width = bor(width,0x40)
-     end
-     PointsBuffer = PointsBuffer .. string.char(width)
- else
-     PointsBuffer = PointsBuffer .. string.char(0)
- end
- if #PointsBuffer > 245 then
-     ParseCommand('draw '..PointsBuffer)
-     PointsBuffer = ''
- end
-end
-function FlushPoints()
- if #PointsBuffer > 0 then
-     ParseCommand('draw '..PointsBuffer)
-     PointsBuffer = ''
- end
-end
-
 -- This could probably use less points and more precision
 -- 700x700 for object space
 function DrawStar(x, y, d, f)
@@ -352,8 +328,12 @@ function dbg()
     end
 end
 
+function onPreviewInit()
+onGameInit()
+end
+
 function onGameInit()
-    MapGen = 2
+    MapGen = mgDrawn
     TemplateFilter = 0
     local TotGen = 0
     local Tries = 0
@@ -363,8 +343,8 @@ function onGameInit()
     local y = 0
     local w = 0
     local h = 0 
-    GameFlags = bor(GameFlags, gfShoppaBorder)
-    if band(GameFlags,gfBottomBorder) == 0 and GetRandom(2) == 0 then
+    if GetGameFlag(gfSolidLand) then EnableGameFlags(gfShoppaBorder) end
+    if not GetGameFlag(gfBottomBorder) and GetRandom(2) == 0 then
         AddPoint(-50,2010,7)
         AddPoint(4150,2010)
         for i = 0,GetRandom(3) do
